@@ -19,6 +19,7 @@ import os
 import sys
 import json
 import logging
+import logging.config
 import requests
 import re
 import shutil
@@ -35,8 +36,11 @@ class CLI(object):
         self.cmds.description = "Development environment for big data applications"
         self.cmds.version = ferry.__version__
         self.cmds.usage = "ferry COMMAND [arg...]"
-        self.cmds.add_option("-m", "--mode", "Deployment mode")
         self.cmds.add_option("-c", "--conf", "Deployment configuration")
+        self.cmds.add_option("-l", "--log", "Log configuration file")
+        self.cmds.add_option("-k", "--key", "Specify key directory")
+        self.cmds.add_option("-m", "--mode", "Deployment mode")
+        self.cmds.add_option("-u", "--upgrade", "Upgrade Ferry")
         self.cmds.add_cmd("clean", "Clean zombie Ferry processes")
         self.cmds.add_cmd("server", "Start all the servers")
         self.cmds.add_cmd("deploy", "Deploy a service to the cloud")
@@ -376,7 +380,7 @@ class CLI(object):
         elif(cmd == 'snapshots'):
             return self._list_snapshots()
         elif(cmd == 'install'):
-            msg = self.installer.install(args)
+            msg = self.installer.install(args, options)
             self.installer._stop_docker_daemon()
             return msg
         elif(cmd == 'clean'):
@@ -422,13 +426,7 @@ class CLI(object):
     
 def main(argv=None):
     # Set up the various logging facilities 
-    console = logging.StreamHandler(stream=sys.stderr)
-    console.setFormatter(logging.Formatter(fmt='[%(asctime)s] %(message)s', 
-                                           datefmt='%m/%d/%Y %I:%M:%S'))
-    console.setLevel(logging.WARNING)
-    root_logger = logging.getLogger()
-    root_logger.addHandler(console)
-    root_logger.setLevel(logging.DEBUG)
+    logging.config.fileConfig(FERRY_HOME + "/logging.conf")
 
     cli = CLI()
     if(sys.argv):
@@ -437,6 +435,8 @@ def main(argv=None):
 
             # Initialize the cli
             options = cli.cmds.get_options()
+            if '-l' in options:
+                logging.config.fileConfig(options['-l'][0])
 
             # Execute the commands
             all_cmds = cli.cmds.get_cmds()
